<?php

namespace Modules\Jiesuan\Services;

use Illuminate\Support\Facades\DB;

class CompanyUserMoneyService
{
    /**
     * 公司管理员用户金额详情
     * @param $companyUid
     * @return null | object
     * <pre>
     * {
     *      'company_uid' : 1, // 公司管理员uid
     *      'total_income' : 1, // 总收入,
     *      'total_dakuan' :1, //已打款金额
     *      'total_tuikuan' : 1, // 总退款金额
     *      'tixian_money' : 1, // 审核中提现金额
     *      'yue_money' : 1, // 当前余额
     * }
     * </pre>
     */
    public static function userMoneyInfo($companyUid)
    {
        $moneyInfo = DB::table('company_user_money')
            ->where('company_uid', $companyUid)
            ->select('total_income', 'total_dakuan', 'total_tuikuan', 'company_uid')
            ->first();
        if(!$moneyInfo) {
            return (object)[
                'company_uid' => $companyUid,
                'total_income' => 0,
                'total_dakuan' => 0,
                'total_tuikuan' => 0,
                'tixian_money' => 0,
                'yue_money' => 0,
            ];
        }

        $tixian_money = DB::table('tixian_records')
            ->where('company_uid', $companyUid)
            ->whereIn('status', [1, 3])
            ->sum('tixian_money');

        $moneyInfo->tixian_money = $tixian_money;
        $moneyInfo->yue_money = $moneyInfo->total_income - $moneyInfo->total_tuikuan - $moneyInfo->total_dakuan - $tixian_money;
        return $moneyInfo;
    }
}
